ClientRequest

Enum ClientRequest 

pub enum ClientRequest {
    DownloadBlob {
        url: String,
        destination: ClientEnd<BlobWriterMarker>,
        header_timeout: i64,
        body_timeout: i64,
        resumption_attempt_limit: u32,
        responder: ClientDownloadBlobResponder,
    },
}
An HTTP client for package resolution and OTAs.

Variants



DownloadBlob

Makes an HTTP GET request for url and writes the response body to destination.

As long as forward progress is being made (response stream contains some body bytes before terminating early), this method will repeatedly (up to resumption_attempt_limit) make follow-up HTTP GET requests with the RANGE header set to the outstanding content.

  • request url the URL of the file to be downloaded.
  • request destination where the file will be written.
  • request header_timeout the timeout to use when waiting for the entire HTTP response header to be downloaded.
  • request body_timeout the timeout to use when waiting for every chunk of bytes while downloading the HTTP response body.
  • request resumption_attempt_limit the number of resumption attempts to make.
  • response size the size in bytes of the downloaded file.

Fields

header_timeout: i64
body_timeout: i64
resumption_attempt_limit: u32

Implementations

Source

impl ClientRequest

pub fn into_download_blob( self, ) -> Option<(String, ClientEnd<BlobWriterMarker>, i64, i64, u32, ClientDownloadBlobResponder)>

pub fn method_name(&self) -> &'static str

Name of the method defined in FIDL