ClientSynchronousProxy

Struct ClientSynchronousProxy 

pub struct ClientSynchronousProxy { /* private fields */ }

Implementations

Source

impl ClientSynchronousProxy

pub fn new(channel: Channel) -> Self

pub fn into_channel(self) -> Channel

pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<ClientEvent, Error>

Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.

pub fn download_blob( &self, url: &str, destination: ClientEnd<BlobWriterMarker>, header_timeout: i64, body_timeout: i64, resumption_attempt_limit: u32, ___deadline: MonotonicInstant, ) -> Result<ClientDownloadBlobResult, Error>

Makes an HTTP GET request for url and writes the response body to destination.

As long as forward progress is being made (response stream contains some body bytes before terminating early), this method will repeatedly (up to resumption_attempt_limit) make follow-up HTTP GET requests with the RANGE header set to the outstanding content.

  • request url the URL of the file to be downloaded.
  • request destination where the file will be written.
  • request header_timeout the timeout to use when waiting for the entire HTTP response header to be downloaded.
  • request body_timeout the timeout to use when waiting for every chunk of bytes while downloading the HTTP response body.
  • request resumption_attempt_limit the number of resumption attempts to make.
  • response size the size in bytes of the downloaded file.