pub struct ClientProxy { /* private fields */ }Implementations
Sourceimpl ClientProxy
impl ClientProxy
Sourcepub fn take_event_stream(&self) -> ClientEventStream
pub fn take_event_stream(&self) -> ClientEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn download_blob(
&self,
url: &str,
destination: ClientEnd<BlobWriterMarker>,
header_timeout: i64,
body_timeout: i64,
resumption_attempt_limit: u32,
) -> QueryResponseFut<ClientDownloadBlobResult, DefaultFuchsiaResourceDialect>
pub fn download_blob( &self, url: &str, destination: ClientEnd<BlobWriterMarker>, header_timeout: i64, body_timeout: i64, resumption_attempt_limit: u32, ) -> QueryResponseFut<ClientDownloadBlobResult, DefaultFuchsiaResourceDialect>
Makes an HTTP GET request for url and writes the response body to destination.
As long as forward progress is being made (response stream contains some body bytes before
terminating early), this method will repeatedly (up to resumption_attempt_limit) make
follow-up HTTP GET requests with the RANGE header set to the outstanding content.
- request
urlthe URL of the file to be downloaded. - request
destinationwhere the file will be written. - request
header_timeoutthe timeout to use when waiting for the entire HTTP response header to be downloaded. - request
body_timeoutthe timeout to use when waiting for every chunk of bytes while downloading the HTTP response body. - request
resumption_attempt_limitthe number of resumption attempts to make.
- response
sizethe size in bytes of the downloaded file.